# Generated by Django 2.1.7 on 2019-07-22 07:51

import ckeditor_uploader.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0012_auto_20190423_1552'),
    ]

    operations = [
        migrations.AddField(
            model_name='page',
            name='mobile_content',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, null=True, verbose_name='모바일 페이지 내용'),
        ),
        migrations.AddField(
            model_name='page',
            name='mobile_style',
            field=models.TextField(blank=True, default='', null=True, verbose_name='CSS'),
        ),
        migrations.AddField(
            model_name='page',
            name='template',
            field=models.CharField(blank=True, default='', max_length=256, null=True, verbose_name='커스텀 템플릿'),
        ),
        migrations.AlterField(
            model_name='page',
            name='content',
            field=ckeditor_uploader.fields.RichTextUploadingField(verbose_name='PC 페이지 내용'),
        ),
        migrations.AlterField(
            model_name='page',
            name='style',
            field=models.TextField(blank=True, default='', null=True, verbose_name='CSS'),
        ),
        migrations.AlterField(
            model_name='post',
            name='cate',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='page.PostCategory'),
        ),
    ]



from django.contrib import admin
from django.core.cache import cache
from reversion.admin import VersionAdmin

from page.models import Page, Pagelet, DownloadableFile, Post, PostCategory, Slide, Popup


class SlideInline(admin.StackedInline):
    sortable = "order"
    model = Slide
    extra = 0

    def save_model(self, request, obj, form, change):
        super().save_model(request, obj, form, change)
        cache.clear()


class PopupInline(admin.StackedInline):
    model = Popup
    extra = 0


@admin.register(Page)
class PageAdmin(VersionAdmin):
    list_display = ['title', 'code', 'id', 'page_type_icon', 'updated', 'created']
    inlines = [SlideInline, PopupInline]

    date_hierarchy = 'created'
    fieldsets = (
        (None, {
            'fields': ('code', 'page_type', 'title', 'subtitle', 'featured')
        }),
        ('PC 환경 컨텐츠', {
            'fields': ('content', 'style'),
        }),
        ('모바일 환경 컨텐츠', {
            'classes': ('collapse',),
            'fields': ('mobile_content', 'mobile_style'),
        }),
        ('커스터마이징', {
            'classes': ('collapse',),
            'fields': ('template','script'),
        }),
        ('기록', {
            'fields': ('updated', 'created'),
        }),
    )
    readonly_fields = ('updated', 'created')

    def page_type_icon(self, obj):
        return {
            'root': '루트',
            'main': '메인',
            'home': '루트+메인'
        }.get(obj.page_type, "")


    page_type_icon.readonly=True
    page_type_icon.short_description = "페이지 타입"

    def save_model(self, request, obj, form, change):
        super().save_model(request, obj, form, change)
        cache.clear()


@admin.register(Pagelet)
class PageletAdmin(VersionAdmin):
    list_display = ['title', 'code', 'id', 'updated', 'created']

    def save_model(self, request, obj, form, change):
        super().save_model(request, obj, form, change)
        cache.clear()


@admin.register(DownloadableFile)
class DownloadableFileAdmin(VersionAdmin):
    list_display = ['name', 'file', ]
    date_hierarchy = 'created'

    def save_model(self, request, obj, form, change):
        super().save_model(request, obj, form, change)
        cache.clear()


@admin.register(Post)
class PostAdmin(VersionAdmin):
    list_display = ['title', 'active', 'topmost', 'created', 'cate']
    list_editable = ['active', 'topmost']
    list_filter = ['cate', 'active', 'topmost']
    date_hierarchy = 'created'

    def save_model(self, request, obj, form, change):
        super().save_model(request, obj, form, change)
        cache.clear()


@admin.register(PostCategory)
class PostCategoryAdmin(admin.ModelAdmin):

    def save_model(self, request, obj, form, change):
        super().save_model(request, obj, form, change)
        cache.clear()



from django import template
from django.conf import settings
from django.shortcuts import render
from django.urls import reverse

from page.shortcode import unpack_content_with_request


def render_page(request, page_obj):
    if request.user_agent.is_mobile and page_obj.mobile_content:
        raw_content = page_obj.mobile_content
    else:
        raw_content = page_obj.content

    content = unpack_content_with_request(request, raw_content, {
        'title': page_obj.title,
        'edit': reverse('admin:page_page_change', args=[page_obj.id])
    })

    template_name = page_obj.template or 'page/page/page.html'

    return render(request, template_name, {
        'page': page_obj,
        'content': content,
        'edit': reverse('admin:page_page_change', args=[page_obj.id]),
        'default_featured': settings.PAGE_FEATURED_DEFAULT if hasattr(settings, "PAGE_FEATURED_DEFAULT") else ''
    })


def render_post(request, post_obj):

    content = unpack_content_with_request(request, post_obj.content)

    return render(request, 'page/post/post.html', {
        'title': post_obj.title,
        'post': post_obj,
        'content': content,
        'cate': post_obj.cate,
        'edit': reverse('admin:page_post_change', args=[post_obj.id]),
        'default_featured': settings.PAGE_FEATURED_DEFAULT if hasattr(settings, "PAGE_FEATURED_DEFAULT") else ''
    })


# Generated by Django 2.1.7 on 2020-01-01 14:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0013_auto_20190722_1651'),
    ]

    operations = [
        migrations.AddField(
            model_name='page',
            name='special',
            field=models.CharField(choices=[(None, '일반 페이지'), ('root', '루트 페이지'), ('main', '메인 페이지'), ('home', '루트 + 메인')], default=None, help_text='\n    랜딩 페이지: 처음 사이트에 진입하면 푀시되는 사이트 입니다. 페이지 코드와 무관하게 루트 주소 "/"를 갖습니다.\n    메인 페이지: 페이지 내에서 첫페이지로 돌아갈 때에 목적지가 되는 페이지 입니다. 로고나 \'처음으로\' 버튼등에 링크됩니다.\n    랜딩 + 메인: 대부분의 사이트에서 홈페이지에 해당 됩니다.\n    ', max_length=10, null=True, verbose_name='특별한 페이지'),
        ),
        migrations.AlterField(
            model_name='page',
            name='code',
            field=models.SlugField(help_text='페이지 url로 사용됩니다. 단, "home"의 경우 예외적으로 루트가 됩니다.', unique=True, verbose_name='페이지 코드'),
        ),
        migrations.AlterField(
            model_name='page',
            name='mobile_style',
            field=models.TextField(blank=True, default='', help_text='스타일 시트에 추가할 내용(테그 없이 작성)', null=True, verbose_name='CSS'),
        ),
        migrations.AlterField(
            model_name='page',
            name='script',
            field=models.TextField(blank=True, default='', help_text='페이지에 추가할 스크립트 내용(테그 없이 작성)', null=True, verbose_name='Script'),
        ),
        migrations.AlterField(
            model_name='page',
            name='style',
            field=models.TextField(blank=True, default='', help_text='스타일 시트에 추가할 내용(테그 없이 작성)', null=True, verbose_name='CSS'),
        ),
        migrations.AlterField(
            model_name='page',
            name='template',
            field=models.CharField(blank=True, default='', help_text='사이트 기본 템플릿(page.html)을 사용하지 않고 별도 템플릿을 사용하려는 경우 지정', max_length=256, null=True, verbose_name='커스텀 템플릿'),
        ),
    ]



# Generated by Django 2.1.7 on 2020-01-01 14:44

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0014_auto_20200101_2339'),
    ]

    operations = [
        migrations.RenameField(
            model_name='page',
            old_name='special',
            new_name='page_type',
        ),
    ]
